agent-runbook-0.1.0 is not a library.
Visit the last successful build:
agent-runbook-0.1.3
Runbook
Runbook scans the current project and machine so AI coding agents can choose the right tools before they start changing files.
CLI
Skill
The Codex skill lives at skills/runbook-skill. Install it through the Skills CLI:
To install globally for supported agents:
Discoverable skill distribution is handled by https://skills.sh/. The runbook CLI itself is distributed through Cargo.